#[non_exhaustive]pub enum DefinedNameInvalidReason {
ParseError,
CircularReference,
UnresolvedName,
InvalidReference,
}Expand description
Reason a reachable defined-name formula is invalid against the immutable workbook snapshot.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ParseError
The selected or reachable formula does not parse.
CircularReference
A non-callable value-name chain contains a cycle.
UnresolvedName
A reachable name is absent from its applicable scope chain.
InvalidReference
A static reference names an absent sheet, table, column, or invalid range.
Implementations