pub enum FormulaCapability {
Supported,
Unsupported(Vec<CalculationIssue>),
}Expand description
Static grammar and function-surface capability for one formula.
Variants
Supported
The formula grammar and referenced function surface are supported.
Unsupported(Vec<CalculationIssue>)
One or more capabilities required by the formula are unavailable.