pub fn supported_function_catalog() -> Vec<FunctionCatalogEntry>Expand description
Returns the deterministic catalog of function names implemented by this build.
The catalog includes official legacy aliases and the internal Google-export compatibility function, which is marked as non-official.